Mute captured audio for 600ms instead of 300ms to avoid having the signaltone be part of the recording.

related-to-bug: 2090229
diff --git a/android/author/android_audio_input.cpp b/android/author/android_audio_input.cpp
index a36cd02..27d647a 100644
--- a/android/author/android_audio_input.cpp
+++ b/android/author/android_audio_input.cpp
@@ -35,9 +35,9 @@
 // Define entry point for this DLL
 OSCL_DLL_ENTRY_POINT_DEFAULT()
 
 // At the start of a recording we are going to mute the first 300ms in
 // order to eliminate recording of the videorecorder signaltone.
-static const int32 AUTO_RAMP_START_MS = 300;
+static const int32 AUTO_RAMP_START_MS = 600;
 
 // After the initial mute we're going to linearly ramp up the volume
 // over the next 300ms.
@@ -35,9 +35,9 @@
 OSCL_DLL_ENTRY_POINT_DEFAULT()
 
-// At the start of a recording we are going to mute the first 300ms in
+// At the start of a recording we are going to mute the first 600ms in
 // order to eliminate recording of the videorecorder signaltone.